@@ -248,19 +248,73 @@ class StateModifierNode(Runnable):
 
         # Collect input variables from state
         input_data = {}
+        
         for var in self.input_variables:
             if var in state:
                 input_data[var] = state.get(var)
-
+        type_of_output = type(state.get(self.output_variables[0])) if self.output_variables else None
         # Render the template using Jinja
-        from jinja2 import Template
-        rendered_message = Template(self.template).render(**input_data)
+        import json
+        import base64
+        from jinja2 import Environment
+
+        def from_json(value):
+            """Convert JSON string to Python object"""
+            try:
+                return json.loads(value)
+            except (json.JSONDecodeError, TypeError) as e:
+                logger.warning(f"Failed to parse JSON value: {e}")
+                return value
+        
+        def base64_to_string(value):
+            """Convert base64 encoded string to regular string"""
+            try:
+                return base64.b64decode(value).decode('utf-8')
+            except Exception as e:
+                logger.warning(f"Failed to decode base64 value: {e}")
+                return value
+        
+
+        env = Environment()
+        env.filters['from_json'] = from_json
+        env.filters['base64ToString'] = base64_to_string
+        
+        template = env.from_string(self.template)
+        rendered_message = template.render(**input_data)
         result = {}
         # Store the rendered message in the state or messages
         if len(self.output_variables) > 0:
             # Use the first output variable to store the rendered content
             output_var = self.output_variables[0]
-            result[output_var] = rendered_message
+            
+            # Convert rendered_message to the appropriate type
+            if type_of_output is not None:
+                try:
+                    if type_of_output == dict:
+                        result[output_var] = json.loads(rendered_message) if isinstance(rendered_message, str) else dict(rendered_message)
+                    elif type_of_output == list:
+                        result[output_var] = json.loads(rendered_message) if isinstance(rendered_message, str) else list(rendered_message)
+                    elif type_of_output == int:
+                        result[output_var] = int(rendered_message)
+                    elif type_of_output == float:
+                        result[output_var] = float(rendered_message)
+                    elif type_of_output == str:
+                        result[output_var] = str(rendered_message)
+                    elif type_of_output == bool:
+                        if isinstance(rendered_message, str):
+                            result[output_var] = rendered_message.lower() in ('true', '1', 'yes', 'on')
+                        else:
+                            result[output_var] = bool(rendered_message)
+                    elif type_of_output == type(None):
+                        result[output_var] = None
+                    else:
+                        # Fallback to string if type is not recognized
+                        result[output_var] = str(rendered_message)
+                except (ValueError, TypeError, json.JSONDecodeError) as e:
+                    logger.warning(f"Failed to convert rendered_message to {type_of_output.__name__}: {e}. Using string fallback.")
+                    result[output_var] = str(rendered_message)
+            else:
+                result[output_var] = rendered_message
 
         # Clean up specified variables (make them empty, not delete)
         
@@ -584,6 +638,11 @@ def create_graph(
             entry_point = clean_string(schema['entry_point'])
         except KeyError:
             raise ToolException("Entry point is not defined in the schema. Please define 'entry_point' in the schema.")
+        # if state.items():
+        #     state_default_node = StateDefaultNode(default_vars=set_defaults(state))
+        #     lg_builder.add_node(state_default_node.name, state_default_node)
+        #     lg_builder.set_entry_point(state_default_node.name)
+        #     lg_builder.add_conditional_edges(state_default_node.name, TransitionalEdge(entry_point))
         for key, value in state.items():
             if 'type' in value and 'value' in value:
                 # set default value for state variable if it is defined in the schema
@@ -633,6 +692,24 @@ def create_graph(
     )
     return compiled.validate()
 
+def set_defaults(d):
+    """Set default values for dictionary entries based on their type."""
+    type_defaults = {
+        'str': '',
+        'list': [],
+        'int': 0,
+        'float': 0.0,
+        'bool': False,
+        # add more types as needed
+    }
+    for k, v in d.items():
+        # Skip 'input' key as it is not a state initial variable
+        if k == 'input':
+            continue
+        # set value or default if type is defined
+        if 'value' not in v:
+            v['value'] = type_defaults.get(v['type'], None)
+    return d
 
 def convert_dict_to_message(msg_dict):
     """Convert a dictionary message to a LangChain message object."""
@@ -679,7 +756,7 @@ class LangGraphAgentRunnable(CompiledStateGraph):
         
         # Append current input to existing messages instead of overwriting
         if input.get('input'):
-            current_message = HumanMessage(content=input.get('input'))
+            current_message = input.get('input')[-1]
             if input.get('messages'):
                 # Ensure existing messages are LangChain objects
                 input['messages'] = [convert_dict_to_message(msg) for msg in input['messages']]
